@@ -2,10 +2,10 @@ from nose.tools import eq_
 
 from .. import tokenization
 
-def test_simple_split():
+def test_wikitext_split():
 	
 	eq_(
-		list(tokenization.simple_split("foo bar herp {{derp}}")),
+		list(tokenization.wikitext_split("foo bar herp {{derp}}")),
 		["foo", " ", "bar", " ", "herp", " ", "{{", "derp", "}}"]
 	)
 	
\ No newline at end of file
